# ldgm <img align="right" width="145" height="120" src="https://github.com/awohns/ldgm/blob/main/docs/ldgm_logo.png">
[![CircleCI](https://circleci.com/gh/awohns/ldgm.svg?style=svg)](https://circleci.com/gh/awohns/ldgm)
[![codecov](https://codecov.io/gh/awohns/ldgm/branch/main/graph/badge.svg?token=2I8PxyDm8A)](https://codecov.io/gh/awohns/ldgm)
[![Documentation Status](https://readthedocs.org/projects/ldgm/badge/?version=latest)](https://ldgm.readthedocs.io/en/latest/?badge=latest)

LDGMs (<ins>L</ins>inkage <ins>D</ins>isequilibrium <ins>G</ins>raphical <ins>M</ins>odels) are sparse and accurate models of linkage disequilibrium (LD) which massively accelerate matrix algebra computations in statistical genetics.

Please refer to the [documentation](https://ldgm.readthedocs.io/en/latest/) for information on installing and using the software.

Please cite this paper if you use LDGMs in published work.
> Pouria Salehi Nowbandegani, Anthony Wilder Wohns, Jenna L. Ballard, Eric S. Lander, Alex Bloemendal, Benjamin M. Neale, and Luke J. O’Connor (2023) _Extremely sparse models of linkage disequilibrium in ancestrally diverse association studies_. Nat Genet. DOI: 10.1038/s41588-023-01487-8
